@@ -1,4 +1,3 @@
-#library('MASS')
 fstep.qiao <-
 function(X,T,kernel){
 	# Initialization
@@ -18,11 +17,13 @@ function(X,T,kernel){
 	Hw = as.matrix(Hw)
 
 	# Cholesky decomposition of t(Hw) %*% Hw
-	Rw = chol(t(Hw)%*%Hw)
-# browser()
+	if (nrow(X)>p)Rw = chol(t(Hw)%*%Hw) else {
+		gamma = 0.5
+		Rw = chol(t(Hw)%*%Hw + gamma*diag(p))}
+
 	# LASSO & SVD
 	Binit = eigen(ginv(cov(X))%*%(t(Hb)%*%Hb))$vect[,1:d]
-	if (is.complex(Binit)) Binit = matrix(as.real(Binit),ncol=d,byrow=F)
+	if (is.complex(Binit)) Binit = matrix(Re(Binit),ncol=d,byrow=F)
 	B = Binit
 	res.svd = svd(t(ginv(Rw))%*%t(Hb)%*%Hb%*%B)
 	A = res.svd$u %*% t(res.svd$v)	
